
#include <ESP8266WiFi.h>
#include <WiFiUdp.h>
#include <ArduinoOTA.h>
#include <PubSubClient.h>
#include "FOST02.h"

//#define DEBUG

#define HOSTNAME "OTA-FOST02"                   // Hostename. The setup function adds the Chip ID at the end.

// Specify data and clock connections and instantiate FOST02 object
#define dataPin  4
#define clockPin 5
FOST02 FOST02(dataPin, clockPin);

const char* ssid = "xxxxxxxx";
const char* password = "xxxxxxxxx";
const char* mqtt_server = "192.168.0.99";

void WiFiStart(void);

// MQTT
unsigned long mqttStartSecond = 0;
unsigned long mqttSecond = 500;

unsigned long tempStartSecond = 0;
unsigned long tempSecond = 30000;

WiFiClient espClient;
PubSubClient mqttclient(mqtt_server,1883,0,espClient); // callback

void setup()
{

#ifdef DEBUG
  Serial.begin(115200);
  Serial.println("");
  Serial.println("REBOOT");
#endif
 
  // Set Hostname.
  String hostname(HOSTNAME);
  WiFi.hostname(hostname);
 
  // inital connect
  WiFi.mode(WIFI_STA);
  WiFiStart();

  // Start OTA server.
  ArduinoOTA.setHostname((const char *)hostname.c_str());
  ArduinoOTA.begin();

  // Start MQTT server.
  mqttStartSecond = 0; // millis();

//  FOST02.setStatus();
}

void loop()
{
  float temp_c;
  float humidity;

  // check if WLAN is connected
  if (WiFi.status() != WL_CONNECTED)
  {
    WiFiStart();
  }

  ArduinoOTA.handle();                      // Handle OTA server.

  if ((!mqttclient.connected()) && (millis() > (mqttStartSecond + mqttSecond)))
  {
    mqttclient.connect("ESP-FOST1");   // clientID,willTopic,willQoS,willRetain,willMessage
    if (!mqttclient.connected())
    {
      mqttStartSecond = millis();      // wenn nicht connected neue aktuelle ms merken und wieder 5s warten
    }
  }  

  if (millis() > tempStartSecond + tempSecond)
  {
    // Read values from the sensor
    temp_c = FOST02.readTemperatureC();
    humidity = FOST02.readHumidity();
    
#ifdef DEBUG
    // Print the values to the serial port
    Serial.print("Temperature: ");
    Serial.print(temp_c, 1);
    Serial.print(" C  ");
    Serial.print("Humidity: ");
    Serial.print(humidity,1);
    Serial.println(" %");
#endif

    if (mqttclient.connected())
    {   
      char out_array[16];
      String output;
      output = String(temp_c, 1) + " C";
      output.toCharArray(out_array,output.length() + 1);
      mqttclient.publish("Fost1/Temperatur", out_array);
      output = String(humidity,1) + "%";
      output.toCharArray(out_array,output.length() + 1);
      mqttclient.publish("Fost1/Feuchte", out_array);
    }
    tempStartSecond = millis();     
  }
  mqttclient.loop();
}

// ------------------------------------------------------------------------

void WiFiStart()
{
  WiFi.begin(ssid, password);

  while (WiFi.status() != WL_CONNECTED)
  {
    delay(500);
  }
}

// ------------------------------------------------------------------------

