/*--------------------------------------------------
v0.5 MSoft 27.02.2016
4MBit-Flash: 512k(no SPIFFS), DIO, NodeMCU
--------------------------------------------------*/

#include <ESP8266WiFi.h>
#include <ESP8266mDNS.h>
#include <WiFiUdp.h>
#include <ArduinoOTA.h>
#include <PubSubClient.h>

#define HOSTNAME "OTA-RELAIS1"                   // Hostename. The setup function adds the Chip ID at the end.

#define relaisPin 5

const char* ssid = "xxxxxxxx";
const char* password = "xxxxxxx";
const char* mqtt_server = "192.168.0.99";

void WiFiStart(void);
void callback(char* topic, byte* payload, unsigned int length);

unsigned long mqttStartSecond = 0;
unsigned long mqttSecond = 5000;

// MQTT
WiFiClient espClient;
PubSubClient mqttclient(mqtt_server, 1883, callback, espClient);

void setup()
{
  digitalWrite(relaisPin, LOW);
  pinMode(relaisPin, OUTPUT);
  
  // Set Hostname.
  String hostname(HOSTNAME);
  WiFi.hostname(hostname);
 
  // inital connect
  WiFi.mode(WIFI_STA);
  WiFiStart();

  // Start OTA server.
  ArduinoOTA.setHostname((const char *)hostname.c_str());
  ArduinoOTA.begin();

  mqttclient.setServer(mqtt_server, 1883);
  mqttclient.setCallback(callback);
  mqttStartSecond = millis(); 
}

void loop()
{
  // check if WLAN is connected
  if (WiFi.status() != WL_CONNECTED)
  {
    WiFiStart();
  }

  ArduinoOTA.handle();                      // Handle OTA server.

  if ((!mqttclient.connected()) && (millis() > (mqttStartSecond + mqttSecond)))
  {
    if (mqttclient.connect("ESP-Relais-1"))
    {
      mqttclient.subscribe("Relais1");
    }
    else
    {
      mqttStartSecond = millis();      // wenn nicht connected neue aktuelle ms merken und wieder 5s warten
    }
  }  

  mqttclient.loop();
}

// ----------------------------------------------------------------------

void WiFiStart()
{
  // Connect to WiFi network

  WiFi.begin(ssid, password);

  while (WiFi.status() != WL_CONNECTED)
  {
    delay(500);
  }
}

// ------------------------------------------------------------------------

void callback(char* topic, byte* payload, unsigned int length)
{ 
  String tempstring;
  for (int i=0; i<length; i++)
  {
    tempstring += (char)payload[i];
  }

  if (tempstring == "ein")
  {
    digitalWrite(relaisPin, HIGH);
  }
  else if (tempstring == "aus")
  {
    digitalWrite(relaisPin, LOW);
  }   
}



